#
# spec file for package vale
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vale
Version:        3.9.5
Release:        1.3
Summary:        CLI tool to lint text with extensible markup format support
License:        MIT
Group:          Productivity/Text/Utilities
URL:            https://github.com/errata-ai/vale
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  golang(API) >= 1.23

%description
Vale is a command-line tool that brings code-like linting to prose. It's fast,
cross-platform (Windows, macOS, and Linux), and highly customizable.

Vale has support for markup: Vale has a rich understanding of many markup
formats, allowing it to avoid syntax-related false positives and intelligently
exclude code snippets from prose-related rules.

Vale includes a highly customizable extension system capable of enforcing your
style-be it a standard editorial style guide or a custom in-house set of rules
(such as those created by GitLab, Homebrew, Linode, CockroachDB, and Spotify).

https://vale.sh/

%prep
%autosetup -a 1

%build
# Build the binary.
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build \
   -tags extended \
   ./cmd/%{name}

%check
# execute the binary as a basic check
./%{name} --help

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
# Install empty styles directory for use by other packages
install --directory %{buildroot}%{_datarootdir}/%{name}/styles

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
# Package empty styles directory for use by other packages
%dir %{_datarootdir}/%{name}
%dir %{_datarootdir}/%{name}/styles

%changelog
* Thu Feb  6 2025 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.9.5:
  * refactor: remove testify
  * chore: upgrade twine
  * fix: revert baseStyles merge
- Packaging improvements:
  * Update to BuildRequires: golang(API) >= 1.23 matching go.mod
* Thu Jan 23 2025 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.9.4. There have been reports that the vale
  config file has changed in a recent release. The CLI utility
  could exit with panic in some config cases. Calling the vale
  subcommand "vale sync" wil "Download and install external
  configuration sources" and restore normal CLI tool operation.
  * test: update `dicpath`
  * refactor: use default location when `dicpath` is not set
  * test: add JSON example
  * refactor: restrict spell check to word bounded tokens
  * fix: only use on-disk file extension for config-matching
  * docs: update widget
  * test: add real YAML example
  * refactor: use new `system` pkg
  * refactor: fix golangci
  * refactor: create test case for symlinks
  * fix: handle empty replacements
  * chore: update vulnerable go dependencies (#938)
  * refactor: remove `allowedScopes`
  * feat: support custom scopes with `engine: tree-stitter`
  * refactor: support assigning markup type per-scope
  * refactor: re-name struct fields
  * Update accept.txt
  * Introducing Vale Guru on Gurubase.io (#924)
  * refactor: operation -> query
  * chore: upgrade /x/crypto and /x/net
  * refactor: fix golangci
  * fix: #944
  * feat: add support for JSON, YAML, and TOML
* Thu Jan  2 2025 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.9.3:
  * refactor: ensure JSON errors always include the same keys
  * feat: allow escaping "|" in substitution rules
* Thu Jan  2 2025 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.9.2:
  * fix: handle regex-based replacements
  * refactor: only fetch library when needed
  * chore: update ruby dependencies (#937)
  * docs: fix demo image
  * refactor: fix golangci
  * fix: check `qErr != nil` but return a nil value error `err` (#935)
  * refactor: support JSON in `ls-dirs`
  * fix: don't hide `minAlertLevel`
  * fix: show all alerts by default
  * refactor: fix golangci
  * refactor: support storing filters in `config`
* Mon Nov 18 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.9.1:
  * fix: support overriding `MinAlertLevel`
  * feat: add command for mocking the config pipeline
  * test: more `repetition` cases
  * fix: improve `Vale.Repetition`
  * fix: check if we need to load a rule before trying
* Fri Nov  8 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.9.0:
  * test: update comment cases
  * feat: add comment syntax for ignoring individual matches (#844)
  * chore: formatting
  * feat: add comment syntax for switching styles (#772)
  * test: add sections
  * docs: update logos
  * test: add MDX case
  * chore: bump Go version
* Tue Oct 15 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.8.0:
  * Update action version
  * chore: Update workflow to match README example
  * chore: update Go and golangci
  * refactor: fix golangci
  * chore: run golangci on PRs
  * feat: Allow users to override comment delimiters (#900)
  * refactor: improve action-related error messages
  * chore: update github checkout to v3 (#896)
  * fix: Add support for multi platform image builds in docker (#897)
  * fix: ensure `skip` dimensions are valid
* Sun Aug 25 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.7.1:
  * feat: add queries for Julia
  * feat: add tree-sitter for Julia
  * fix: wrong message in cases with no index
  * fix: don't apply `ignorecase` to `matchToken`
  * chore: disable cross compile for now
* Sun Jul 21 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.7.0:
  * refactor: display action results in `message`
  * feat: add capture group support to `substitution`
  * refactor: support capture groups in `substitution`
  * chore: remove `funlen` check
  * fix: handle conatenating nested lists
  * chore: add `TARGETARCH`
  * chore: fix version in .goreleaser.yml
* Sun Jul 21 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.6.1:
  * golangci lint (#822)
  * fix: sort commands before printing
  * chore: build statically on Windows
  * docs: clean up README
  * chore: restrict fossa to source files
  * refactor: error on misplaced core-level settings
  * chore: update fossa version
  * Fix broken link in README.md (#853)
  * chore: `cinst` -> `choco install`
  * docs: update link to examples
  * fix: check for `token.Skip` before re-order
* Wed Jun 19 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.6.0:
  * chore: add mingw dep
  * feat: support exceptions in `Repetition`
  * chore: add `build-base` to Docker [ci skip]
* Sun Jun  9 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.5.0:
  * chore: fix CC/CXX entries
  * chore: remove deprecated "replacements"
  * chore: update cross version
  * chore: fix version
  * docs: add deprecation note
  * chore: CGO_ENABLED=1
  * chore: switch to `jdkato/choco-cross`
  * chore: add stage for GoReleaser dry run
  * chore: fix workflow spacing
  * chore: add step for testing release
  * chore: switch to `goreleaser-cross`
  * chore: upgrade tree-sitter
  * docs: Add xsltproc and dita to prerequisites (#842)
  * feat: YAML, CSS, and Protocol Buffers
  * refactor: deprecate regex-based comment parsing
  * feat: JavaScript support
  * feat: C/C++ support
  * feat: Ruby support
  * feat: Rust support
  * feat: Python support
  * feat: support multi-line, line-scope comments
  * refactor: fix `callRst` on Windows
  * refactor: fix rst error formatting
  * chore: install docutils
  * chore: enable CGO for AppVeyor
  * feat: tree-sitter powered fragments
  * docs: fix OC embed [ci skip]
  * test: fix local env
  * feat: multiple queries
  * test: add another rst case
  * refactor: move to JSON-formatted tests
  * refactor: move comment processing to tree-sitter
  * docs: remove old review link
- Packaging:
  * Add BuildRequires: gcc-c++ required by linked C++ library:
    github.com/smacker/go-tree-sitter/yaml
* Wed May  1 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.4.2:
  * test: fix invalid pkg case
  * test: add another cascade case
  * Fix substitution rule parsing (#813)
  * chore(deps): bump golang.org/x/net from 0.17.0 to 0.23.0 (#809)
  * docs: add Digital Ocean
* Mon Apr  8 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.4.1:
  * fix: fallback to default config when syncing
  * feat: add `capitalize` option in `substitution`
  * fix: only match case for `ignorecase: true`
  * docs: add demo screenshot [ci skip]
* Mon Apr  8 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.4.0:
  * chore: fix Appveyor
  * chore: new windows workflow
  * test: add another `occurrence` case
  * refactor: clean comments after updating
  * fix: restrict `reLinkRef` to single lines
  * fix: ensure `alt` text is reset in the walker
  * feat: support displaying the count of `occurance`
  * fix: handle no matches
  * fix: omit whitespace matches
  * refactor: fix golangci-lint
  * refactor: create `nlp.StrLen`
  * fix: take first non-code match in occurance rules
  * test: add AsciiDoc comment cases
  * docs: fix `Vale.Terms`
* Mon Mar 25 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.3.1:
  * refactor: use `pterm.Fuzzy` instead of `Gray`
  * refactor: clean up sync progress bar
  * docs: fix typos (#794)
  * feat: support `replace` in `capitalization`
* Mon Mar 11 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.3.0:
  * fix: ensure `StylesPath` is created with `sync`
  * feat: support showing expected case in `message`
  * chore: update twine to v0.10.1
* Tue Mar  5 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.2.2:
  * fix: use `utf8.RuneCountInString` for offsets
  * refactor: remove rst/adoc scripts
  * refactor: fix golangci-lint
  * fix: ensure `getNativeConfig` is consistent
* Fri Mar  1 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.2.1:
  * chore: bump twine to v0.10.0
  * refactor: use actual path for assigned formats
  * chore: bump Docker to golang:1.21
* Fri Mar  1 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.2.0:
  * feat: support script-based actions
  * feat: allow `script`-based rules to use local files
  * feat: support `prefix` key in `capitalization`
  * chore: bump twine to v0.9.0
  * feat: match case in `Substitution`s default action
  * docs [skip ci]: add note about default threshold
  * chore: bump twine to v0.8.1
  * fix: ensure `capitalization` respects `vocab: false`
  * feat: proto support (#777)
  * feat: add `--no-global`
  * refactor: better install details
  * fix: don't double-report install errors
  * refactor: add CLI help text for host commands
  * fix: remove duplicate $home prefix
  * refactor: check action params
* Sun Feb 18 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.1.0:
  * refactor: update chrome ID
  * refactor: revert #748
  * refactor: use `AddConfigFile`
  * refactor: add `cfg.SearchPaths()`
  * refactor: show var value in `ls-dirs` if set
  * feat: add `ls-vars` command
  * feat: add support for `VALE_STYLES_PATH`
  * refactor: fix golangci
  * feat: add comment syntax for switching styles (#748)
  * refactor: `sync` should initialize `.vale-config`
  * docs: update contributing instructions (#767)
  * chore: revert `minAlertLevel`
* Wed Feb  7 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.0.7:
  * refactor: "Location" -> "Default Location"
  * chore: pterm requires Go v1.21
  * chore: upgrade pterm
  * fix: handle `sync` with relative `--config`
- Packaging improvements:
  * _service set_version remove param basename since autodetects OK
  * Update to BuildRequires: golang(API) >= 1.21 matching go.mod
* Wed Feb  7 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.0.6:
  * refactor: fix golangci
  * fix: remove `-q` from asciidoctor args
  * fix: don't double-report error context
  * feat: support fragments in `.ps1` and `.jl` files
  * fix: local config files should be in pipeline
  * fix: add `.json` to `nativeHostName`
  * feat: add `vale-native` to `ls-dirs`
  * feat: add extension management commands
  * feat: add `transform` api command
  * chore: increase minAlertLevel
  * refactor: fix benchmarks
  * chore: bump module path
  * refactor: fix golangci-lint issues
  * chore: bump branch in workflow
* Wed Jan 17 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.0.5:
  * refactor: don't load `Vale` if it's not needed
  * test: add another spelling case
  * fix: ensure `applyPatterns` respects `formats`
* Wed Jan 17 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.0.4:
  * fix: better support for phrases in vocabularies
  * fix: use file paths when applying ignore patterns
  * refactor: move ini-related functions to ini.go
  * test: add vocab to example
  * test: add case for `substitution` determinism
  * refactor: add `Found` column to `ls-dirs`
* Wed Jan 17 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.0.3:
  * fix: don't error on missing default files
* Wed Jan 17 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.0.2:
  * refactor: better error message for default styles
* Thu Jan 11 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.0.1:
  * test: add more package cases
  * fix: respect alternative ways to set a base
  * test: add more source tests
  * docs: add famewall
* Wed Jan 10 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 3.0.0:
  * refactor: use xdg lib for config and styles
  * refactor: make `sync` root-relative
  * feat: sync with multiple config files
  * refactor: update table header in `ls-dirs`
  * test: add more config cases
  * chore: mod tidy
  * refactor: `path` -> `filepath`
  * fix: ensure default values are set
  * feat: default `StylesPath`
  * fix: add `--no-global`
  * fix: update error message
  * refactor: add styling
  * feat: add global config location to `--h`
  * feat: fallback to global when no config is found
  * fix: handle relative StylePaths
  * fix: ensure all matching sections are applied
  * refactor: update StylesPath
  * refactor: load default config last
  * feat: add default config
  * feat: `sync` supports new `config` dir
  * fix: `NOSUGGEST` may be more than 1 char
  * fix: ensure meta characters are escaped
  * test: add case for vocab
  * fix: golangci
  * refactor: new `config/ignore` directory
  * refactor: fix golangci-lint
  * refactor: load files from `config/dictionaries`
  * chore(deps): bump golang.org/x/crypto from 0.14.0 to 0.17.0 (#741)
  * refactor: new `StylesPath` layout
  * feat: new `StylesPath/config` directory
  * docs: add GitHub sponsors
* Wed Dec  6 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 2.30.0:
  * test: add Julia tests
  * Julia Support (#731)
  * feat: config validation
  * feat: config I/O
* Mon Nov 20 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 2.29.7:
  * fix: add implicit `(?-i)` flags
  * chore: bump twine to v0.8.0
  * Remove Digital Ocean
* Fri Oct 20 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 2.29.6:
  * chore: bump twine to 0.7.0
  * feat: support exception regex in `sentence`
* Mon Oct 16 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 2.29.5:
  * fix: ignore link refs when looking for matches
  * chore: drop `jdkato/regexp`
  * fix: bump twine to 0.6.1
* Mon Oct 16 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
  * Use %%%%name macro where applicable to normalize common lines
    across Go app packages. Also makes renaming binary easier when
    required to handle package name conflict.
* Fri Oct 13 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 2.29.4:
  * fix: check bounds in `sentence`
* Fri Oct 13 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 2.29.3:
  * test: add another capitalization case
  * chore(deps): bump golang.org/x/net from 0.14.0 to 0.17.0 (#703)
  * feat: add vocab support to `$title`
  * refactor: add support for `indicators`
  * refactor: use `jdkato/twine/strcase`
  * refactor: drop `prose` dep
  * fix: skip `metric` for empty files
  * fix: don't crash on multi-line comments
  * refactor: look for .adoc comments at line start
* Fri Oct  6 2023 jkowalczyk@suse.com
- Update to version 2.29.2:
  * fix: don't fail when $HOME isn't defined
  * fix: ignore custom IDs
  * refactor: use our new glob package
  * fix: `gobwas/glob` -> `bmatcuk/doublestar`
  * refactor: rollback case change for now
  * feat: ensure suggestions match case of token
- Packaging improvements:
  * Fix E: summary-too-long Summary: must not exceed 79 characters
* Fri Oct  6 2023 jkowalczyk@suse.com
- Update to version 2.29.1:
  * fix: don't shift the offset for large files
  * chore: new action
* Fri Oct  6 2023 jkowalczyk@suse.com
- Update to version 2.29.0:
  * test: add case for `script` with custom message
  * fix: fragments should only be assigned for markup
  * test: add TypeScript case
  * feat: Add Optional Custom Message to Script Match (#682)
  * fix: Remove additional `--update` for apk in Dockerfile (#675)
* Thu Sep  7 2023 jkowalczyk@suse.com
- Update to version 2.28.3:
  * fix: workaround `blk.Line` inconsistency
  * fix: take the best match, when available
  * fix: don't concatenate an empty regex
  * fix: `metric` shouldn't error on empty files
  * fix: ignore statichcheck for seqence history
  * chore: fix workflow branch for golangci
  * test: update expected error message
  * chore: add workflow for golangci
  * chore: get `cmd` passing new CI config
  * chore: get `check` passing new CI config
  * chore: get `core` passing new ci config
  * chore: get `spell` passing new ci config
  * chore: get `nlp` passing new ci config
  * chore: get `lint` passing new golangci config
  * chore: update `goldmark` and `net`
* Thu Aug 17 2023 jkowalczyk@suse.com
- Update to version 2.28.2:
  * test: add case for pkg 404
  * fix: improve error message for non-existant pkgs
  * docs: add 'Appwrite' to vocab
  * docs: add Appwrite
* Tue Jul 25 2023 jkowalczyk@suse.com
- Update to version 2.28.1:
  * fix: ensure hypenated exceptions are respected
  * fix: allow hypenated words in `Vale.Terms`
  * test: fix inline scope cases
  * refactor: validate `scope`
* Tue Jul  4 2023 jkowalczyk@suse.com
- Update to version 2.28.0:
  * fix: set base path for `VALE_CONFIG_PATH`
  * feat: support `VALE_CONFIG_PATH`
  * fix: normalizePath tilde expansion on Windows (#656)
  * fix: update GitLab CI
  * feat: add clojure support (#649)
  * refactor: make capitalization threshold `>=`
  * docs: typo
  * fix: broken README.md link
  * Update README.md (#638)
* Tue May 23 2023 jkowalczyk@suse.com
- Update to version 2.27.0:
  * test: add more Package cases
  * feat: support ignoring `comment` scopes
  * fix: ensure `raw`-scoped rules are run on code
* Thu May 11 2023 jkowalczyk@suse.com
- Update to version 2.26.0:
  * test: add case for dics in `StylesPath`
  * refactor: support templates in `StylesPath`
  * fix: allow `-` in `code::` blocks
  * chore: fix `make compare`
  * chore: clean up Makefile
  * refactor: deprecate dedicated inline scopes
  * refactor: deprecate dedicated inline scopes
  * refactor: fallback to CLI if local server fails
  * docs: Add DigitalOcean
* Thu Apr 27 2023 jkowalczyk@suse.com
- Update to version 2.25.2:
  * fix: rollback file view changes for now
* Thu Apr 27 2023 jkowalczyk@suse.com
- Update to version 2.25.1:
  * fix: revert godirwalk upgrade
  * chore: fix AppVeyor
  * chore: bump Go in Docker
* Thu Apr 27 2023 jkowalczyk@suse.com
- Update to version 2.25.0:
  * chore: fix version
  * chore: bump checkout
  * chore: upgrade GoReleaser [ci skip]
  * chore: bump Go
  * test: fix templates
  * chore: update `godirwalk`
  * refactor: add NOTE about `os`
  * test: add another template case
  * chore: update Go to 1.20
  * refactor: use `unsafe.StringData` to keep multiple file views
  * feat: support comment-based config on Org Mode
  * docs: add NOTE about `Substitute`
  * refactor: use `Strings.Replace` in `Substitute`
  * chore: add `make profile`
  * chore: update `go-org`
  * chore: update sprig
  * chore: fix `make bench`
  * chore: update `archiver`
  * chore: bump Go version
  * test: add fuzzing to `existence`
  * chore: remove redundant section from feat template
  * chore: remove word-wrapping
  * chore: fix bug report wording
- Packaging: BuildRequires: golang(API) >= 1.20
* Thu Apr 27 2023 jkowalczyk@suse.com
- Update to version 2.24.4:
  * fix: don't call `re2loc` in `script`-based rules
  * fix: support symlinks in `dicpath`
  * docs: Add Studio to README
  * New ISSUE_TEMPLATE
  * chore: move `CODE_OF_CONDUCT`
  * Create CODE_OF_CONDUCT.md
  * fix: check bounds on tags
  * test: add case for custom threshold
  * test: add Packages tests
  * fix: check bounds for `scope: raw`
* Tue Apr 18 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Remove NO_BRP_STRIP_DEBUG=true experimentally to test which if
  any platforms in OBS currently produce invalid Go binaries when
  calling brp-15-strip-debug from brp-check-suse.
  Refs boo#1210938
  * Go packages %%define __arch_install_post export NO_BRP_STRIP_DEBUG=true
  * Available in golang-packaging as macro go_nostrip
  * go_nostrip is one of the only golang-packaging macros still
    useful after Go modules without a full rewrite or replacement
  * Also remove spec comment "# nodebug"
  * GNU strip circa 2016 would incorrectly strip Go intermediate
    step .a archives and write out an invalid binary instead of
    erroring.
  * Error manifested as fmt.a: go archive is missing __.PKGDEF
    on OBS built Go binaries which had passed their build step
  * Upstream issue reported in 2016 as
    https://github.com/golang/go/issues/17890
  * brp-check-suse PR https://github.com/openSUSE/brp-check-suse/pull/7
    closed in 2019 due to age, needs follow-up on current versions
* Tue Apr 18 2023 jkowalczyk@suse.com
- Update to version 2.24.3:
  * test: add `occurrence` case
  * fix: don't crash on no `extends`
* Sun Apr 16 2023 jkowalczyk@suse.com
- Update to version 2.24.2:
  * fix: ensure `negate` is always checked for tags
  * fix: don't make tmpdir for local pkg
  * fix: set config defaults
  * refactor: don't require config for metrics
  * refactor: don't require config in `run`
  * feat: better error for unknown keys
  * refactor: don't require `.vale.ini` for `compile`
  * refactor: match case in returned suggestions
  * chore: update choco
* Sun Apr  9 2023 jkowalczyk@suse.com
- Update to version 2.24.1:
  * refactor: unknown keys are now an error
  * (GH-597) Find config in home folder as last resort (#598)
  * feat: support multi-part selectors
  * (MAINT) Add tests for PowerShell code linting (#586)
- Use _service mode manual as better alias name than disabled
* Mon Mar  6 2023 jkowalczyk@suse.com
- Update to version 2.24.0:
  * fix: string -> interface
  * refactor: drop `bindata` dep
  * feat: support negated scopes
  * fix: use a temp dir in `loadLocalPkg`
  * feat: improve handling for misplaced keys
  * chore: fix `.ArtifactName`
* Tue Feb 28 2023 jkowalczyk@suse.com
- Update to version 2.23.3:
  * chore: fix naming again
* Tue Feb 28 2023 jkowalczyk@suse.com
- Update to version 2.23.2:
  * fix: asset naming scheme
* Tue Feb 28 2023 jkowalczyk@suse.com
- Update to version 2.23.1:
  * chore: remove `id`
  * chore: remove `--clean`
  * chore: fix `name_template`
  * chore: remove `archives.replacements`
  * chore: fix GoReleaser
  * chore: clean up workflows
  * fix: CLI test isn't deterministic
  * fix: include `.vale.ini` in action tests
  * chore: bring back `chocolateys`
  * test: start action cases
  * refactor: remove old TODO
  * refactor: remove `pkg`
  * fix: handle trailing commas in listing block
  * Add PowerShell as a supported code language (#579)
  * feat: support Typescript, TSX and JSX files (#564)
  * fix: use `determinePath` in `Transform`
  * fix: ignore empty tokens
  * fix: trim leading newlines from sentences
* Sat Feb 11 2023 jkowalczyk@suse.com
- Update to version 2.23.0:
  * fix: create `lintTxt`
  * chore: update go.mod
  * feat: add `--filter`
  * feat: Add pre-commit support (#558)
  * chore: update runner name
  * Add `perf` workflow
  * docs: fix typos (#553)
  * chore: set version for Docker
* Wed Jan 18 2023 jkowalczyk@suse.com
- Update to version 2.22.0:
  * chore: disable choco step for now
  * chore: add `ldflags`
  * chore: add `goos` section
  * chore: specify `choco` version
  * chore: install `choco`
  * chore: fix docker version
  * Add choco section to GoReleaser
  * Remove `atom` files
  * refactor: remove outdated `HasUpdate` check
  * Allow for more generic errors in loadPkg (#543)
  * Fix dic count
  * fix: add `SM` to metric
  * docs: update year
  * chore: fix excutable name
  * feat: install package from local directory (#534)
  * chore: use `docker buildx`
* Wed Dec 14 2022 jkowalczyk@suse.com
- Update to version 2.21.3:
  * refactor: remove debug message
  * fix: always use last `StylesPath` loaded
  * feat(config): expand ~ to home directory (#530)
  * refactor: remove `ioutil`
  * fix: don't treat `span` as a block
* Thu Nov 24 2022 jkowalczyk@suse.com
- Update to version 2.21.2:
  * fix: allow `.vale` in `StylesPath`
  * fix: allow `.vale` in `StylesPath`
  * refactor: add note about `os` module
  * feat: enable access to `os` module in `script`
* Thu Nov 24 2022 jkowalczyk@suse.com
- Update to version 2.21.1:
  * test: re-enable Non-Existent case
  * refactor: remove `StylesPath` from example config
  * fix: remove override logic from `loadConfig`
  * feat: support using local and system dics
  * docs: comment typo
  * fix: correctly resolve `dicpath`
  * Add CodeQL workflow
  * feat: enable Goldmark's footnote extension
  * chore: ignore `.fleet`
  * refactor: align structs
  * fix: report exact Asciidoctor error
* Fri Oct 28 2022 jkowalczyk@suse.com
- Update to version 2.21.0:
  * test: add another case for `IgnoredClasses`
  * refactor: report actual XML error message
  * test: add table test case for `IgnoredClasses`
  * docs: update `.vale.ini` config
  * docs: update `.vale.ini` config
  * docs: update `.vale.ini` config
  * feat: support comments in ignore files
  * feat: ignore blocks by class
  * fix: handle `0` suffix
  * fix: `skip` should be an upper bound
  * fix: `skip` should be an upper bound
  * fix: ensure sequence length is non-zero
  * feat: load local packages
  * chore: restore Dockerfile
  * chore: restore Dockerfile
* Wed Oct 12 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Add empty directory /usr/share/vale/styles for use by other
  packages to install vale styles. Use a shortname directory per
  style package, e.g. /usr/share/vale/styles/suse
* Wed Sep 14 2022 jkowalczyk@suse.com
- Update to version 2.20.2:
  * chore: fix main package
  * chore: fix Go version for GoReleaser
  * refactor: remove old doc.go
  * refactor: remove old doc.go
  * Consistent color reporting
  * refactor: remove unused error
  * refactor: remove `internal/cli`
  * refactor: remove `internal/cli`
  * fix: support numbers in Vocab entries
* Sun Jul 24 2022 jkowalczyk@suse.com
- Update to version 2.20.1:
  * refactor: fix `IsPhrase` tests
  * test: add tests for `IsPhrase`
  * refactor: add missing `doc.go`
  * fix: set action params
  * fix: improve error message
  * fix: check all error conditions
  * Fix: Enable PIE mode
  * Fix: Remove exec bit from docs
  * docs: add Org support
* Tue Jul  5 2022 jkowalczyk@suse.com
- Update to version 2.20.0:
  * chore: add workflow to bump pkgs
  * fix: check `head` indexes before removing
  * feat: support ignore patterns in Org
  * chore: bump Go version
  * test: add another Org case
  * feat: add support for Org files
* Fri Jul  1 2022 jkowalczyk@suse.com
- Initial package version 2.19.0:
  * chore: add dispatch step
  * refactor: remove unused param
  * feat: support tag matching for sequence anchor
  * chore: build linux_arm64
  * chore: move fixtures to testdata
  * chore: move pkg managers to their own repo
  * chore: add chocolatey files
  * feat: more patterns
  * refactor: remove manual offset
  * fix: use line index as comment offset
  * chore: mark fixtures as vendored
  * chore: remove lgtm.yml
  * chore: mark `testdata` as vendored
  * feat: support embedded markup
  * docs: update link
